==> jbig2dec_0.19.orig.tar.gz: jbig2dec-0.19/jbig2_hufftab.h <==
/* Copyright (C) 2001-2020 Artifex Software, Inc.
   All Rights Reserved.

   This software is provided AS-IS with no warranty, either express or
   implied.

   This software is distributed under license and may not be copied,
   modified or distributed except as expressly authorized under the terms
   of the license contained in the file LICENSE in this distribution.

   Refer to licensing information at http://www.artifex.com or contact
   Artifex Software, Inc.,  1305 Grant Avenue - Suite 200, Novato,
   CA 94945, U.S.A., +1(415)492-9861, for further information.
*/

/*
    jbig2dec
*/

/* predefined Huffman table definitions
    -- See Annex B.5 of the JBIG2 specification */

#ifndef _JBIG2_HUFFTAB_H
#define _JBIG2_HUFFTAB_H

extern const Jbig2HuffmanParams jbig2_huffman_params_A;
extern const Jbig2HuffmanParams jbig2_huffman_params_B;
extern const Jbig2HuffmanParams jbig2_huffman_params_C;
extern const Jbig2HuffmanParams jbig2_huffman_params_D;
extern const Jbig2HuffmanParams jbig2_huffman_params_E;
extern const Jbig2HuffmanParams jbig2_huffman_params_F;
extern const Jbig2HuffmanParams jbig2_huffman_params_G;
extern const Jbig2HuffmanParams jbig2_huffman_params_H;
extern const Jbig2HuffmanParams jbig2_huffman_params_I;
extern const Jbig2HuffmanParams jbig2_huffman_params_J;
extern const Jbig2HuffmanParams jbig2_huffman_params_K;
extern const Jbig2HuffmanParams jbig2_huffman_params_L;
extern const Jbig2HuffmanParams jbig2_huffman_params_M;
extern const Jbig2HuffmanParams jbig2_huffman_params_N;
extern const Jbig2HuffmanParams jbig2_huffman_params_O;

#endif /* _JBIG2_HUFFTAB_H */

==> jbig2dec_0.20.orig.tar.gz: jbig2dec-0.20/jbig2_hufftab.h <==
/* Copyright (C) 2001-2023 Artifex Software, Inc.
   All Rights Reserved.

   This software is provided AS-IS with no warranty, either express or
   implied.

   This software is distributed under license and may not be copied,
   modified or distributed except as expressly authorized under the terms
   of the license contained in the file LICENSE in this distribution.

   Refer to licensing information at http://www.artifex.com or contact
   Artifex Software, Inc.,  39 Mesa Street, Suite 108A, San Francisco,
   CA 94129, USA, for further information.
*/

/*
    jbig2dec
*/

/* predefined Huffman table definitions
    -- See Annex B.5 of the JBIG2 specification */

#ifndef _JBIG2_HUFFTAB_H
#define _JBIG2_HUFFTAB_H

extern const Jbig2HuffmanParams jbig2_huffman_params_A;
extern const Jbig2HuffmanParams jbig2_huffman_params_B;
extern const Jbig2HuffmanParams jbig2_huffman_params_C;
extern const Jbig2HuffmanParams jbig2_huffman_params_D;
extern const Jbig2HuffmanParams jbig2_huffman_params_E;
extern const Jbig2HuffmanParams jbig2_huffman_params_F;
extern const Jbig2HuffmanParams jbig2_huffman_params_G;
extern const Jbig2HuffmanParams jbig2_huffman_params_H;
extern const Jbig2HuffmanParams jbig2_huffman_params_I;
extern const Jbig2HuffmanParams jbig2_huffman_params_J;
extern const Jbig2HuffmanParams jbig2_huffman_params_K;
extern const Jbig2HuffmanParams jbig2_huffman_params_L;
extern const Jbig2HuffmanParams jbig2_huffman_params_M;
extern const Jbig2HuffmanParams jbig2_huffman_params_N;
extern const Jbig2HuffmanParams jbig2_huffman_params_O;

#endif /* _JBIG2_HUFFTAB_H */
